<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:di="http://www.w3schools.com">
	<xsl:variable name="nCols" select="5" />
	<xsl:output method="html" version="4.0" encoding="utf-8" indent="yes"/>
	<xsl:template match="/">
		<html>
			<head>
				<link href="ActinicCatalog.css" rel="stylesheet" type="text/css"/>
				<script type="text/javascript">
<![CDATA[
   function hideShow(id, el)
		{
      var elId = document.getElementById(id);
      if (elId)
			{
         elId.style.display = (elId.style.display == "none") ? "block" : "none";
			}
      if (el)
			{
         el.innerHTML = (el.innerHTML == '(Hide)') ? '(Show)' : '(Hide)';
			}
		}

   function onScrollUpdate()
		{
      var elToc = document.getElementById('toc');
      if (elToc)
			{
         var posY = getScrollY();
         elToc.style.top = posY + 50 + "px";
			}
		}

   function getScrollY()
		{
      var scrOfY = 0;
      if( typeof( window.pageYOffset ) == 'number' )
			{
         //Netscape compliant
         scrOfY = window.pageYOffset;
			}
		else if( document.body && ( document.body.scrollLeft || document.body.scrollTop ) )
			{
         //DOM compliant
         scrOfY = document.body.scrollTop;
			}
		else if( document.documentElement &&
         ( document.documentElement.scrollLeft || document.documentElement.scrollTop ) )
			{
         //IE6 standards compliant mode
         scrOfY = document.documentElement.scrollTop;
			}
      return (scrOfY);
		}

   if (window.addEventListener) { window.addEventListener("scroll", onScrollUpdate, false); }
   else if (window.attachEvent) { window.attachEvent("onscroll",onScrollUpdate); }
	]]>
</script>
			</head>
			<body>
				<div class="wrapper">
					<xsl:apply-templates/>
				</div>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="di:contents">
		<div class="toc" id="toc">
		<div class="toc_header" onclick="hideShow('toc_content')">Table Of Content</div>
			<div class="toc_content" id="toc_content">
				<ol>	
				<xsl:apply-templates/>
				</ol>
			</div>
		</div>
	</xsl:template>

	<xsl:template match="di:contents/*">
		<li><a><xsl:attribute name="href">#<xsl:value-of select="@name"/></xsl:attribute><xsl:value-of select="@name"/></a></li>
	</xsl:template>

	<xsl:template match="di:tables">
		<div class="table_content">
			<xsl:apply-templates/>
		</div>		
	</xsl:template>

	<xsl:template match="di:table">
		<a name="{@name}"/><b><h1 class="table"><xsl:value-of select="@name"/></h1></b>
		<table>
			<tr>
				<th align='left'>Field Name</th>
				<th align='left'>Data Type</th>
				<th align='left'>Default Value</th>
				<th align='left'>Description</th>
				<th align='left'>ValidationInfo</th>
				<th align='left'>Linked to</th>
			</tr>
			<xsl:apply-templates/>
		</table>
	</xsl:template>

	<xsl:template match="di:field">
		<tr>
			<td><xsl:value-of select="@name"/></td>
			<xsl:apply-templates/>
			<td><xsl:call-template name="fnRelationships"/></td>
		</tr>
	</xsl:template>

	<xsl:template match="di:field/*">
		<xsl:if test="name()!='Relationship'">
			<td><xsl:apply-templates/></td>
		</xsl:if>
	</xsl:template>
      
	<xsl:template match="di:field/*" mode="ColumnHeaders">
		<th align='left'>
			<!-- Put the value of the *name* of the current element -->
			<xsl:value-of select="name(.)"/>
		</th>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo">
		<xsl:choose>
			<xsl:when test="*">
				<td>
					<table width="100%" border="1" cellpadding="2">
						<xsl:apply-templates/>
					</table>
				</td>
			</xsl:when>
			<xsl:otherwise>
				<td></td>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo/*">
			<tr>
				<th><xsl:value-of select="name()" /></th>
				<td><xsl:apply-templates/></td>
			</tr>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo/AllowedValues/*">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo/AllowedValues/Name">
		<code><xsl:value-of select="Class"/>::<xsl:value-of select="Enum"/></code>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo/AllowedValues/EnumName">
		<code><xsl:apply-templates/></code>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo/AllowedValues/Items">
		<table><xsl:apply-templates/></table>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo/AllowedValues/Items/Item">
		<tr>
			<td><code><xsl:value-of select="Name"/></code></td>
			<td><code><xsl:value-of select="Value"/></code></td>
			<td><xsl:value-of select="ItemDescription"/></td>
		</tr>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo/Custom/*">
		<ul><xsl:apply-templates/></ul>
	</xsl:template>

	<xsl:template match="di:field/ValidationInfo/Custom/Rule">
		<li>
			<xsl:choose>
				<xsl:when test="Function">
					Function: <code><xsl:value-of select="Function"/>()</code>
					<br/>
				</xsl:when>
				<xsl:when test="Expression">
					Expression: <code><xsl:value-of select="Expression"/></code>
					<br/>
				</xsl:when>
			</xsl:choose>
			<i><xsl:value-of select="Description"/></i>
		</li>
	</xsl:template>
    
	<xsl:template match="di:indexes">
		<tr><td colspan="{$nCols}"><b>Indexes</b></td></tr>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="di:primary">
		<tr><td colspan="{$nCols}"><b>Primary key:</b> <xsl:value-of select="@name"/><b> Clustered:</b> <xsl:value-of select="@clustered"/>
				<b> Fields:</b><xsl:apply-templates/>
			</td></tr>
	</xsl:template>

	<xsl:template match="di:secondary">
		<tr><td colspan="{$nCols}"><b>Secondary key:</b> <xsl:value-of select="@name"/><b> Unique:</b> <xsl:value-of select="@unique"/>
				<b> Fields:</b><xsl:apply-templates/>
			</td></tr>
	</xsl:template>

	<xsl:template match="di:keyfield">
		<xsl:value-of select="@name"/>
		(<xsl:apply-templates/>)
	</xsl:template>

	<xsl:template match="di:keyfield/*">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="di:fixDuplicates">
	</xsl:template>

	<xsl:template match="di:linkto">
		<a>
		<xsl:attribute name="href">
			#<xsl:value-of select="@table"/>
		</xsl:attribute>
		[<xsl:value-of select="@table"/>].[<xsl:value-of select="@target"/>]
		</a>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="di:properties">
		<br />Convert using '<xsl:value-of select="@conversion"/>'
		Records '<xsl:value-of select="@records"/>'

		<xsl:variable name="bNull"><xsl:value-of select="@nullSource"/></xsl:variable>
		<xsl:if test="$bNull='true'">
			Allow null
		</xsl:if>

		<xsl:variable name="bWhere"><xsl:value-of select="@where"/></xsl:variable>
		<xsl:if test="$bWhere!=''">
			<br />Use where clause '<xsl:value-of select="@where"/>'
		</xsl:if>

	</xsl:template>

	<xsl:template match="di:primary">
		<tr><td colspan="{$nCols}"><b>Primary key:</b> <xsl:value-of select="@name"/><b> Clustered:</b> <xsl:value-of select="@clustered"/>
				<b> Fields:</b><xsl:apply-templates/>
			</td></tr>
	</xsl:template>
	
<!--
	*********************************************
	* HTML tag translations
	*********************************************
-->
	<xsl:template match="p">
		<p><xsl:apply-templates/></p>
	</xsl:template>

	<xsl:template match="br">
		<br />
	</xsl:template>

	<xsl:template match="ul">
		<ul><xsl:apply-templates/></ul>
	</xsl:template>

	<xsl:template match="ol">
		<ol>
		<xsl:variable name="nStart">
			<xsl:value-of select="@start"/>
		</xsl:variable>

		<xsl:if test="$nStart!=''">
			<xsl:attribute name="start">
				<xsl:value-of select="$nStart" />
			</xsl:attribute>
		</xsl:if>

		<xsl:apply-templates/>
		</ol>
	</xsl:template>

	<xsl:template match="li">
		<li><xsl:apply-templates/></li>
	</xsl:template>

	<xsl:template match="b">
		<b><xsl:apply-templates/></b>
	</xsl:template>

	<xsl:template match="table">
		<table><xsl:apply-templates/></table>
	</xsl:template>
	
	<xsl:template match="th">
		<th align="left"><xsl:apply-templates/></th>
	</xsl:template>
	
	<xsl:template match="tr">
		<tr><xsl:apply-templates/></tr>
	</xsl:template>
	
	<xsl:template match="td">
		<td><xsl:apply-templates/></td>
	</xsl:template>
	
	<xsl:template match="td_green">
		<td style="background-color:#00FF00"><xsl:apply-templates/></td>
	</xsl:template>
	
	<xsl:template match="td_brown">
		<td style="background-color:#FFCC00"><xsl:apply-templates/></td>
	</xsl:template>
	
	<xsl:template match="td_yellow">
		<td style="background-color:#FFFF00"><xsl:apply-templates/></td>
	</xsl:template>
	
	<xsl:template match="td_cyan">
		<td style="background-color:#00FFFF"><xsl:apply-templates/></td>
	</xsl:template>
	
	<xsl:template match="td_blue">
		<td style="background-color:#7796FF"><xsl:apply-templates/></td>
	</xsl:template>
	
	<xsl:template match="td_purple">
		<td style="background-color:#CC99FF"><xsl:apply-templates/></td>
	</xsl:template>
	
	<xsl:template match="td_gray">
		<td style="background-color:#C0C0C0"><xsl:apply-templates/></td>
	</xsl:template>

<!--
	*********************************************
	* Template functions
	*********************************************
-->
	<xsl:template name="fnRelationships">
		<xsl:if test="Relationship">
			<xsl:if test="Relationship/@table!=''">
				[<xsl:value-of select="Relationship/@table"/>].
			</xsl:if>
			<xsl:if test="Relationship/@field!=''">
				[<xsl:value-of select="Relationship/@field"/>]
			</xsl:if>
			<xsl:if test="Relationship/@custom!=''">
				<xsl:text>Custom relationship</xsl:text>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet> 
