<?php

/**
 * CLogger.php - Logger wrapper class (singleton)
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */

namespace SDExtension\Helper;

use Monolog\Logger;
use Monolog\Handler\StreamHandler;

class CLogger
	{

	/**
	 * @var object $m_oLogger Logger
	 */
	private static $m_oLogger = null;

	/**
	 * @var string $m_sLogRoot LogRoot
	 */
	private static $m_sLogRoot = "";

	/**
	 * @var string $m_sChannel Channel
	 */
	private static $m_sChannel = "default";

	/**
	 * init - Initializing the Logger
	 * 
	 * @access public
	 * @param string $sChannel Channel
	 * @param string $sLogRoot LogRoot
	 * @return void
	 */
	public static function init($sChannel = "default", $sLogRoot = "")
		{
		self::$m_sChannel = $sChannel;
		self::$m_sLogRoot = $sLogRoot;
		self::$m_oLogger = new \Monolog\SDELogger($sChannel);
		$sTraceFilter = \SDExtension\CConfig::get('sdd-configuration.paths.logs.tracefilter', 'W'); // not used yet
		if (empty($sTraceFilter))
			{
			$sTraceFilter = "";
			}
		$bDebug = ((int) \SDExtension\CConfig::get('sdd-configuration.paths.logs.debug', 0) > 0);
		$nLevel = $bDebug ? Logger::DEBUG : Logger::WARNING;
		self::$m_oLogger->pushHandler(new StreamHandler(self::$m_sLogRoot . "extension.log", $nLevel));
		self::$m_oLogger->addInfo("------------------- Logger[$sChannel] is ready");
		}

	/**
	 * initLogToScreen - Logging to Screen
	 * 
	 * @access public
	 * @return void
	 */
	public static function initLogToScreen($bStream = false)
		{
		$sOutputFormat = "[%datetime%] %channel%.%level_name%: %message%";
		$oFormatter = new \Monolog\Formatter\CSdeLineFormatter($sOutputFormat);
		//$formatter = new \Monolog\Formatter\HTMLFormatter();
		if ($bStream)
			{
			$oStreamHandler = new \Monolog\Handler\AjaxStreamHandler(\Monolog\Logger::INFO);
			}
		else
			{
			$oStreamHandler = new \Monolog\Handler\StreamHandler('php://output', \Monolog\Logger::INFO);
			}
		$oStreamHandler->setFormatter($oFormatter);
		self::$m_oLogger->pushHandler($oStreamHandler);
		}

	/**
	 * get - Getting Logger object
	 * 
	 * @access public
	 * @param $sChannel Channel
	 * @param $sLogRoot LogRoot
	 * @return object Logger
	 */
	public static function get($sChannel = "default", $sLogRoot = "")
		{
		if (self::$m_oLogger == null)
			{
			self::init($sChannel, $sLogRoot);
			}
		return self::$m_oLogger;
		}

	}

namespace Monolog;

/**
 * SDELogger - SDE Logger extension class
 *
 */
class SDELogger extends Logger
	{

	/**
	 * addError - Adds a log record at the ERROR level.
	 *
	 * @param  string  $sMessage The log message
	 * @param  array   $aContext The log context
	 * @return Boolean Whether the record has been processed
	 */
	public function addError($sMessage, array $aContext = array())
		{
		//
		// Uncomment this to add debug backtrace
		// if (empty($aContext)) { $aContext = debug_backtrace(); }
		//
		return $this->addRecord(static::ERROR, $sMessage, $aContext);
		}

	}

namespace Monolog\Formatter;

/**
 * CSdeLineFormatter - SDE LineFormatter class
 *
 */
class CSdeLineFormatter extends LineFormatter
	{

	/**
	 * {@inheritdoc}
	 */
	public function format(array $aRecord)
		{
		$sOutput = parent::format($aRecord);
		return str_replace('@@br@@', '<br/>', htmlentities(str_replace('<br/>', '@@br@@', $sOutput))) . BR;
		}

	}
