<?php

/**
 * CValidator.php - Implementation file for DataBase class.
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */

namespace SDExtension\Helper;

class CValidator
	{

	/**
	 * @var object $m_oCatalogDB Catalog DB
	 */
	protected $m_oCatalogDB = null;

	/**
	 * @var object $m_oShippingDB Shipping DB
	 */
	protected $m_oShippingDB = null;

	/**
	 * __construct - Object constructor method
	 *
	 * @access public
	 * @param object $oCatalogDB Catalog Database Object
	 * @param object $oShippingDB Shipping Database Object
	 * @return void
	 */
	public function __construct($oCatalogDB, $oShippingDB)
		{
		$this->m_oCatalogDB = $oCatalogDB;
		$this->m_oShippingDB = $oShippingDB;
		}

	/**
	 * ValidateEmail - Validate Email address
	 *
	 * @access public
	 * @throws ValidatorException 
	 * @param string $sEmail Email address
	 * @return string Email address
	 */
	public function ValidateEmail($sEmail)
		{
		if ($sEmail == "Invalid Request")
			{
			return null;
			}
		if (filter_var($sEmail, FILTER_VALIDATE_EMAIL) === false)
			{
			\SDExtension\Helper\CLogger::get(LOG_CHANNEL_NAME)->addError("#" . EXCEPTION_MSG_INVALID_EMAIL . ":" . EXCEPTION_CODE_INVALID_EMAIL);
			throw new \SDExtension\SDException\ValidatorException(EXCEPTION_MSG_INVALID_EMAIL, EXCEPTION_CODE_INVALID_EMAIL);
			}
		return $sEmail;
		}

	/**
	 * ValidateCurrency - Validate Currency
	 *
	 * @access public
	 * @throws ValidatorException 
	 * @param string $sCurrency Currency
	 * @return string Currency
	 */
	public function ValidateCurrency($sCurrency)
		{
		$aResult = $this->m_oCatalogDB->Select('currencies', '*', [['SINTLSYMBOL', $sCurrency]])->fetch(\PDO::FETCH_ASSOC);
		if (empty($aResult))
			{
			throw new \SDExtension\SDException\InvalidCurrencyException($sCurrency);
			}
		return $sCurrency;
		}

	}
