<?php

/**
 * CDataBase.php - Implementation file for Ms Access DataBase class.
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */

namespace SDExtension\DB;

class CDataBaseAccess extends CDataBase
    {

    /**
     * @var string $m_sColumnQuoteBegin Begin quote sign for DB Columns
     */
    protected $m_sColumnQuoteBegin = "[";

    /**
     * @var string $m_sColumnQuoteEnd End quote sign for DB Columns
     */
    protected $m_sColumnQuoteEnd = "]";

    /**
     * __construct - Object constructor method
     *
     * @access public
     * @param array $aConnectionDetails
     * @return void
     */
    public function __construct($aConnectionDetails, $sDatabaseID)
	{
	$sDsn = arr_get($aConnectionDetails, 'sDsn', '');
	$this->m_sDBUser = arr_get($aConnectionDetails, 'sUser', '');
	$sPassword = arr_get($aConnectionDetails, 'sPassword', '');
	$this->m_sDataBaseID = arr_get($aConnectionDetails, 'sDatabaseID', '');
	$this->m_sDBAuthType = arr_get($aConnectionDetails, 'sDBAuthType', '');
	$this->m_aDataBases = arr_get($aConnectionDetails, 'aDataBases', []);
	try
	    {
	    $this->m_oDB = new \PDO($sDsn, $this->m_sDBUser, $sPassword);
	    }
	catch (\PDOException $oPDOException)
	    {
	    $sDsn = str_replace("Driver={Microsoft Access Driver (*.mdb)", "Driver={Microsoft Access Driver (*.mdb" . ACCDB_STRING . ")", $sDsn);
	    $this->m_oDB = new \PDO($sDsn, $this->m_sDBUser, $sPassword);
	    }
	\SDExtension\Helper\CLogger::get(LOG_CHANNEL_NAME)->addInfo("Connected to Database: $sDatabaseID");
	}

    /**
     * CompileSelectSql - Compiles SQL expression
     * 
     * @access protected
     * @param array $aWhere Array of conditions
     * @return string WHERE statement
     */
    protected function CompileSelectSql($aQuery = [])
	{
	$sSelectSQL = "SELECT";
	if (!empty($aQuery["limit"]))
	    {
	    $sSelectSQL .= " TOP $aQuery[limit] ";
	    }
	if (!empty($aQuery["select"]))
	    {
	    $sSelectSQL .= " $aQuery[select] ";
	    }
	else
	    {
	    $sSelectSQL .= " * ";
	    }
	if (!empty($aQuery["from"]))
	    {
	    $sSelectSQL .= "FROM ";
	    if (!empty($aQuery["join"]))
		{
		$sSelectSQL .= "($aQuery[from] $aQuery[join])";
		}
	    else
		{
		$sSelectSQL .= "$aQuery[from] ";
		}
	    }
	if (!empty($aQuery["where"]))
	    {
	    $sSelectSQL .= "WHERE $aQuery[where] ";
	    }
	if (!empty($aQuery["group_by"]))
	    {
	    $sSelectSQL .= "GROUP BY $aQuery[group_by] ";
	    }
	if (!empty($aQuery["order_by"]))
	    {
	    $sSelectSQL .= "ORDER BY $aQuery[order_by] ";
	    }
	return $sSelectSQL;
	}

    /**
     * ConcatenateJoins - Concatenates JOIN expression
     * 
     * @access protected
     * @param array $aJoinDirections Array of JOIN Directions
     * @param array $aJoinTables Array of JOIN Tables
     * @param array $aJoinOns Array of JOIN ONs
     * @return string JOIN expression
     */
    protected function ConcatenateJoins($aJoinDirections, $aJoinTables, $aJoinOns)
	{
	$sJoins = "";
	$nMaxKey = count($aJoinTables) - 1;
	foreach (array_reverse($aJoinTables) as $nKey => $sJoinTable)
	    {
	    $sJoinTmp = "";
	    if (empty($sJoins))
		{
		$sJoinTmp = " $sJoinTable ";
		}
	    else
		{
		$sJoinTmp = " ($sJoinTable $sJoins) ";
		}
	    $sJoins = arr_get($aJoinDirections, $nMaxKey - $nKey, "INNER JOIN")
		  . $sJoinTmp
		  . "ON (" . $this->CompileJoinOn(arr_get($aJoinOns, $nMaxKey - $nKey, "")) . ")";
	    }
	return $sJoins;
	}

    /**
     * Sanitize - Sanitizes string
     *
     * @access protected
     * @param string $sData Data to sanitize
     * @return string Sanitized string
     */
    protected function Sanitize($sData)
	{
	$sData = iconv("UTF-8", "WINDOWS-1256", $sData);
	return str_replace("'", "''", $sData);
	}

    /**
     * BoolValue - Converts Boolean to appropriate value depending on driver
     * 
     * @access protected
     * @param bool $bData Boolean value
     * @return int
     */
    protected function BoolValue($bData)
	{
	return $bData ? -1 : 0;
	}

	}
