<?php

/**
 * CImport.php - Abstract Import class.
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */

namespace SDExtension\Import;

abstract class CImport
	{

	/**
	 * @var object $m_oCatalogDB Catalog DB
	 */
	var $m_oCatalogDB;

	/**
	 * @var object $m_oShippingDB Shipping DB
	 */
	var $m_oShippingDB;

	/**
	 * @var object $m_oPersonTable Person Table
	 */
	var $m_oPersonTable = null;

	/**
	 * @var object $m_oOrderDetailTable OrderDetail Table
	 */
	var $m_oOrderDetailTable = null;

	/**
	 * @var object $m_oOrderHistory OrderHistory
	 */
	var $m_oOrderHistory = null;

	/**
	 * @var object $m_oOrderTracking OrderTracking
	 */
	var $m_oOrderTracking = null;

	/**
	 * @var object $m_oPaymentHistory PaymentHistory Table
	 */
	var $m_oPaymentHistory = null;

	/**
	 * @var bool $m_bSetupDone Is Setup Done?
	 */
	protected $m_bSetupDone = false;

	/**
	 * __construct - Object constructor
	 *
	 * @access public
	 * @param object $oCatalogDB Catalog DB
	 * @param object $oShippingDB Shipping DB
	 * @return void
	 */
	public function __construct($oCatalogDB = null, $oShippingDB = null)
		{
		$this->m_oCatalogDB = $oCatalogDB;
		$this->m_oShippingDB = $oShippingDB;
		$this->m_oPersonTable = new \SDExtension\DB\Table\CPerson($oCatalogDB);
		$this->m_oOrderTable = new \SDExtension\DB\Table\COrder($oCatalogDB);
		$this->m_oOrderDetailTable = new \SDExtension\DB\Table\COrderDetail($oCatalogDB);
		$this->m_oPaymentHistory = new \SDExtension\DB\Table\CPaymentHistory($oCatalogDB);
		$this->m_oOrderHistory = new \SDExtension\DB\Table\COrderHistory($oCatalogDB);
		$this->m_oOrderTracking = new \SDExtension\DB\Table\COrderTracking($oCatalogDB);
		$this->m_bSetupDone = false;
		}

	/**
	 * ImportOrders - Object constructor
	 *
	 * @access protected
	 * @param string|int $vBeginDateOrDays Begin Date or Number of Days
	 * @param string $sEndDate End Date
	 * @param string $sStatus Status
	 * @return void
	 */
	abstract protected function ImportOrders($vBeginDateOrDays = 10, $sEndDate = null, $sStatus = DEFAULT_STATUS);

	/**
	 * UpdateOrders - Update Orders
	 *
	 * @access protected
	 */
	abstract protected function UpdateOrders();

	/**
	 * Setup - Setup
	 * 
	 * @access protected
	 * @param array $aSettings Settings
	 */
	abstract protected function Setup($aSettings = []);
	}
