<?php

/**
 * constants.php - Constants for SellerDeck Extenstions Framework
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */
//
// General Constants
//
define('BR', "<br/>\n");
define('DS', DIRECTORY_SEPARATOR);
define('SIMPLE_DATE_FORMAT', 'Y-m-d');
define('SIMPLE_DATETIME_FORMAT', 'Y-m-d H:i');
define('CURRENT_DATE', date(SIMPLE_DATE_FORMAT));
define('SELLERDECK_DATE_FORMAT', 'Y/m/d H:i');
define('SELLERDECK_ALT_DATE_FORMAT', 'm/d/Y h:i:s A'); //Format string is %m/%d/%Y %I:%M:%S %p
define('MAX_INCREASE_ORDER_NUMBER', 5);
define('EXPIRY_LIMIT1', 60 * 60 * 24 * 2); // 2 days
define('EXPIRY_LIMIT2', 60 * 60 * 24 * 7); // 1 week
define('LOCK_FILE', "extension.lock");
define('LOCK_FILE_MAX_AGE', 60); // in seconds
//
// Defaults
//
define('DEFAULT_SITE_NAME', 'Site1');
define('DEFAULT_TIMER_INTERVAL', 15 * 60); // in seconds
define('DEFAULT_WEIGHT', 0.25); // in kilograms
//
// Controller constants
//
define('HTTP_METHOD_GET', 'get');
define('HTTP_METHOD_PUT', 'put');
define('HTTP_METHOD_POST', 'post');
define('CONTROLLER_PARAMETER_ACTION', 'action');
define('CONTROLLER_PARAMETER_FORMAT', 'format');
define('CONTROLLER_DEFAULT_ACTION', 'index');
define('FORMAT_ARRAY', 'array');
define('FORMAT_TEXT', 'text');
define('FORMAT_HTML', 'html');
define('FORMAT_XML', 'xml');
define('FORMAT_PHP', 'php');
define('FORMAT_JSON', 'json');
define('FORMAT_YAML', 'yaml');
define('FORMAT_STREAM', 'stream');
define('STATUS_SUCCESS', 'successs');
define('STATUS_FAIL', 'fail');
//
// EC message types
//
define('API_XML_VERSION', '1');
define('TIMER_CONFIGURATION', 'timer');
define('HANDSHAKE_VERSION_INFORMATION', 'version-information');
define('HANDSHAKE_SDD_CONFIGURATION', 'sdd-configuration');
define('HANDSHAKE_EXTENSION_CONFIGURATION', 'extension-configuration');
define('HANDSHAKE_CONFIGURATION', 'configuration');
//
// Standard paths and URLs
//
define('EXTENSIONS_ROOT', realpath(realpath(__DIR__) . DS . ".." . DS) . DS);
define('EXTENSIONS_APP_ROOT', EXTENSIONS_ROOT . 'app' . DS);
define('EXTENSION_VIEW_ROOT', EXTENSIONS_APP_ROOT . 'views' . DS);
define('EXTENSION_AJAX_VIEW_ROOT', EXTENSION_VIEW_ROOT . 'ajax' . DS);
define('VENDOR_ROOT', EXTENSIONS_ROOT . 'vendor' . DS);
define('FRAMEWORK_ROOT', EXTENSIONS_ROOT . 'framework' . DS);
define('CLASSES_ROOT', FRAMEWORK_ROOT . 'classes' . DS);
define('CONFIG_ROOT', FRAMEWORK_ROOT . 'config' . DS);
define('CLASSES_APP_ROOT', EXTENSIONS_APP_ROOT . 'classes' . DS);
define('CONFIG_APP_ROOT', EXTENSIONS_APP_ROOT . 'config' . DS);
define('INSTALL_ROOT', EXTENSIONS_APP_ROOT . 'install' . DS);
define('DEFAULT_CONFIG_ROOT', CONFIG_ROOT);
define('SETTINGS_INI', EXTENSIONS_ROOT . 'settings.ini');
//
// Configuration constants
//
define('CONFIG_PHP_HEADER', "<?php\n/**\n *  %s\n *\n */\n   return ");
define('CONFIG_PHP_FOOTER', ";\n");
//
// Table name constants
//
define('TABLE_ORDER', 'Order');
define('TABLE_PERSON', 'Person');
define('TABLE_ORDER_DETAIL', 'OrderDetail');
define('TABLE_ORDER_TRACKING', 'OrderTracking');
define('TABLE_ORDER_HISTORY', 'OrderHistory');
define('TABLE_PRODUCT', 'Product');
define('TABLE_PRODUCT_PROPERTIES', 'ProductProperties');
define('TABLE_PAYMENT_HISTORY', 'PaymentHistory');
define('TABLE_CONTROL_INFO', 'ControlInfo');
define('TABLE_WEIGHT_CONFIGURATION', 'WeightConfiguration');
define('TABLE_CATALOG_SECTION', 'Catalog section');
//
// Product Type constants
//
define('PRODUCT_TYPE_NORMAL', 0);
define('PRODUCT_TYPE_DUPLICATE', 1);
define('PRODUCT_TYPE_FRAGMENT', 2);
//
// Product Property Type constants
//
define('PRODUCT_PROPERTY_TYPE_SEARCHABLE_ITEM',1);
define('PRODUCT_PROPERTY_TYPE_ADDITIONAL_PROMPT',2);
define('PRODUCT_PROPERTY_TYPE_HTML_VARIABLE',3);
define('PRODUCT_PROPERTY_TYPE_PRICE_SCHEDULE',4);
define('PRODUCT_PROPERTY_TYPE_COMPONENT',5);
define('PRODUCT_PROPERTY_TYPE_ATTRIBUTE',6);
define('PRODUCT_PROPERTY_TYPE_CHOICE',7);
define('PRODUCT_PROPERTY_TYPE_PERMUTATION',8);
define('PRODUCT_PROPERTY_TYPE_SECTION_CLASSIFICATION',9);
//
// Tax constants
//
define('TAX_MODEL_SIMPLE', 0);
define('TAX_MODEL_ADVANCED', 1);
define('TAX_BY_ALWAYS_TAX', 0);
define('TAX_BY_INVOICE_ADDRESS', 1);
define('TAX_BY_DELIVERY_ADDRESS', 2);
define('ROUND_TAX_PER_ORDER_LINE', 0);
define('ROUND_TAX_PER_ORDER_ITEM', 1);
define('ROUND_TAX_PER_ORDER', 2);
define('TAX_IS_CUMULATIVE_FALSE', 0);
define('TAX_IS_CUMULATIVE_TRUE', 1);
define('ALLOW_EXEMPTION_DISALLOWED', 0);
define('ALLOW_EXEMPTION_ALLOWED', 1);
define('TAX_TREATMENT_ZERO', 0);
define('TAX_TREATMENT_EXEMPT', 1);
define('TAX_TREATMENT_TAX_1_APPLIES', 2);
define('TAX_TREATMENT_TAX_2_APPLIES', 3);
define('TAX_TREATMENT_BOTH_TAX_1_AND_TAX_2_APPLIES', 4);
define('TAX_ROUND_PER_LINE', 0);
define('TAX_ROUND_PER_ITEM', 1);
define('TAX_ROUND_PER_ORDER', 2);
define('TAX_ROUND_TRUNCATION', 0);
define('TAX_ROUND_SCIENTIFIC_DOWN', 1);
define('TAX_ROUND_SCIENTIFIC_NORMAL', 2);
define('TAX_ROUND_CEILING', 3);
define('TAX_ROUND_BANKERS', 4);
//
// Exceptions
//
define('EXCEPTION_MSG_EXTENSION_DISABLED', 'Extension is disabled');
define('EXCEPTION_MSG_SDD_INCOMPATIBLE', 'Extension requires SellerDeck %s or greater');
define('EXCEPTION_MSG_NO_DATA', 'No data on input stream');
define('EXCEPTION_MSG_EXTENSION_NOT_ENABLED_ON_THIS_PC', 'Extension is not enabled on this PC.');
define('EXCEPTION_MSG_CANT_LOAD_EXTENSION', 'Can\'t load extension');
define('EXCEPTION_MSG_CANT_LOAD_SETUP_SQL', 'Can\'t load Setup SQL');
define('EXCEPTION_MSG_CANT_LOAD_CONFIG_FILE', 'Can\'t load config file');
define('EXCEPTION_MSG_INVALID_CURRENCY', 'Invalid currency in the Order record: %s.');
define('EXCEPTION_MSG_INVALID_EMAIL', 'Invalid Email address in the Order record');
define('EXCEPTION_MSG_BULK_REFRESH_ORDERS', 'Error bulk refreshing Orders');
define('EXCEPTION_MSG_BULK_STOCK_UPDATE', 'Error bulk Stock update');
define('EXCEPTION_CODE_EXTENSION_DISABLED', 999);
define('EXCEPTION_CODE_SDD_INCOMPATIBLE', 998);
define('EXCEPTION_CODE_NO_DATA', 997);
define('EXCEPTION_CODE_EXTENSION_NOT_ENABLED_ON_THIS_PC', 996);
define('EXCEPTION_CODE_CANT_LOAD_EXTENSION', 501);
define('EXCEPTION_CODE_CANT_LOAD_SETUP_SQL', 502);
define('EXCEPTION_CODE_CANT_LOAD_CONFIG_FILE', 503);
define('EXCEPTION_CODE_INVALID_CURRENCY', 101);
define('EXCEPTION_CODE_INVALID_EMAIL', 102);
define('EXCEPTION_CODE_NETWORK_ERROR', 700);
define('EXCEPTION_CODE_BULK_REFRESH_ORDERS', 701);
define('EXCEPTION_CODE_BULK_STOCK_UPDATE', 702);
//
// Database Driver IDs
//
define('DB_CLASS_ACCESS', 'CDataBaseAccess');
define('DB_CLASS_ACCESS_NO_PDO', 'CDataBaseAccessNoPDO');
define('DB_CLASS_SQLSERVER', 'CDataBaseSqlServer');
define('DB_TYPE_ACCESS', 'MS Access');
define('DB_TYPE_SQLSERVER', 'MS SQL Server');
define('DB_CATALOG', 'Catalog DB');
define('DB_SHIPPING', 'Shipping DB');
define('DB_COMMON_DBO', 'dbo');
define('DB_AUTH_TYPE_NT', 'NT');
define('DB_AUTH_TYPE_DB', 'DB');
//
// SQL prefixes
//
define('SQL_EXPRESSION_PREFIX', 'EXPR:');
define('SQL_DATA_PREFIX', 'DATA:');
define('SQL_TYPE_INT', 'INT:');
define('SQL_TYPE_STRING', 'STR:');
define('SQL_COLUMN', 'COL:');
//
// Other, Database related constants
//
define('BOOP_OP_AND', 'AND');
define('BOOP_OP_OR', 'OR');
define('MAX_RETRY_BY_INSERT', 5);
define('INCREASE_ID_BY_INSERT', 1);
define('ACCDB_STRING', ', *.accdb');
