<?php

/**
 * bootstrap.php - Bootstrap for SellerDeck Extenstions Framework
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */
//
// Default Timezone
//
date_default_timezone_set('GMT');

if (!defined('HANDSHAKING'))
	{
	define('HANDSHAKING', false);
	}
require_once('constants.php');
//
// Setting up Cache root
//
$sExtensionProgramDataPath = "";
if (file_exists(SETTINGS_INI))
	{
	$aSettings = parse_ini_file(SETTINGS_INI);
	if (isset($aSettings['revision']))
		{
		define('SDE_VERSION_DAYNO', $aSettings['revision']);
		}
	if (isset($aSettings['extension_program_data']))
		{
		$sExtensionProgramDataPath = $aSettings['extension_program_data'];
		define('CACHE_ROOT', $sExtensionProgramDataPath);
		define('DEFAULT_LOG_ROOT', CACHE_ROOT);
		}
	}
else
	{
	define('CACHE_ROOT', EXTENSIONS_ROOT . 'cache' . DS);
	}
if (!file_exists(CACHE_ROOT))
	{
	mkdir(CACHE_ROOT, 0777, true);
	}

//
// SDExtension Framework vendor dependencies
//
if (!is_file(VENDOR_ROOT . 'autoload.php'))
	{
	die('Composer is not installed. Please run "php composer.phar update" in the root to install Composer');
	}
require_once(VENDOR_ROOT . 'autoload.php');
//
// Basic SDExtension Framework dependencies
//
require_once(CLASSES_ROOT . 'AjaxStreamHandler.php');
require_once(CLASSES_ROOT . 'exception/SDException.php');
require_once(CLASSES_ROOT . 'exception/SDExitException.php');
require_once(CLASSES_ROOT . 'helper/Tools.php');
require_once(CLASSES_ROOT . 'CConfig.php');
require_once(CLASSES_ROOT . 'CLogger.php');
if (!HANDSHAKING)
	{
	//
	// Loading basic configurations
	//
    $sDetailsTempPath = CACHE_ROOT . "details_temp.php";
	$aDetailsTemp = load_config($sDetailsTempPath, function() use ($sDetailsTempPath)
		{
		throw new \SDExtension\SDException\SDException(EXCEPTION_MSG_CANT_LOAD_CONFIG_FILE . ": $sDetailsTempPath", EXCEPTION_CODE_CANT_LOAD_CONFIG_FILE);
		});
	$sSiteName = arr_get($aDetailsTemp, 'sSiteName', DEFAULT_SITE_NAME);
	$sSdeLogs = arr_get($aDetailsTemp, 'sSdeLogs', DEFAULT_LOG_ROOT);
	$sSiteSdeDataFolder = arr_get($aDetailsTemp, 'sSiteSdeDataFolder', DEFAULT_CONFIG_ROOT);
	define('LOG_CHANNEL_NAME', $sSiteName);
	define('LOG_ROOT', $sSdeLogs . DS);
	}
//
// Further SDExtension Framework dependencies
//
require_once(CLASSES_ROOT . 'exception/ValidatorException.php');
require_once(CLASSES_ROOT . 'exception/InvalidCurrencyException.php');
require_once(CLASSES_ROOT . 'helper/ExtensionHelper.php');
require_once(CLASSES_ROOT . 'helper/Array2XML.php');
require_once(CLASSES_ROOT . 'helper/XML2Array.php');
require_once(CLASSES_ROOT . 'CValidator.php');
require_once(CLASSES_ROOT . 'CSession.php');
require_once(CLASSES_ROOT . 'CTax.php');
require_once(CLASSES_ROOT . 'CControllerBase.php');
require_once(CLASSES_ROOT . 'soap/CSDApiSoapClient.php');
require_once(CLASSES_ROOT . 'soap/CSDApiSoapJobs.php');
require_once(CLASSES_ROOT . 'import/CFieldMapping.php');
require_once(CLASSES_ROOT . 'import/CImport.php');
//
// Loading non-handshaking SDExtension Framework dependencies 
//
if (!HANDSHAKING)
	{
	$sConfigFileVersion = $sSiteSdeDataFolder . "version.php";
	$sConfigFileDetails = $sSiteSdeDataFolder . "details.php";
	$sVersion = load_config($sConfigFileVersion, function() use ($sConfigFileVersion)
		{
		throw new \SDExtension\SDException\SDException(EXCEPTION_MSG_CANT_LOAD_CONFIG_FILE . ": $sConfigFileVersion", EXCEPTION_CODE_CANT_LOAD_CONFIG_FILE);
		});
	\SDExtension\CConfig::add($sVersion);
	$sDetails = load_config($sConfigFileDetails, function() use ($sConfigFileDetails)
		{
		throw new \SDExtension\SDException\SDException(EXCEPTION_MSG_CANT_LOAD_CONFIG_FILE . ": $sConfigFileDetails", EXCEPTION_CODE_CANT_LOAD_CONFIG_FILE);
		});
	\SDExtension\CConfig::add($sDetails);
	//
	// Display error settings
	//
	$bDebug = ((int) \SDExtension\CConfig::get('sdd-configuration.paths.logs.debug', 0) > 0);
	if ($bDebug)
		{
		error_reporting(E_ALL);
		ini_set('display_errors', 1);
		}
	else
		{
		error_reporting(0);
		@ini_set('display_errors', 0);
		}
	//
	// Init Logger
	//
   @SDExtension\Helper\CLogger::init(LOG_CHANNEL_NAME, LOG_ROOT);
	//
	// Loading non Handshaking classes
	//
    require_once(CLASSES_ROOT . 'database/CDataBase.php');
	require_once(CLASSES_ROOT . 'database/CDataBaseSqlServer.php');
	require_once(CLASSES_ROOT . 'database/CDataBaseAccess.php');
	require_once(CLASSES_ROOT . 'database/CDataBaseAccessNoPDO.php');
	require_once(CLASSES_ROOT . 'database/CDataBaseFactory.php');
	require_once(CLASSES_ROOT . 'database/table/CTable.php');
	require_once(CLASSES_ROOT . 'database/table/catalog/COrderBase.php');
	require_once(CLASSES_ROOT . 'database/table/catalog/COrderDetailBase.php');
	require_once(CLASSES_ROOT . 'database/table/catalog/COrderHistoryBase.php');
	require_once(CLASSES_ROOT . 'database/table/catalog/COrderTrackingBase.php');
	require_once(CLASSES_ROOT . 'database/table/catalog/CPaymentHistoryBase.php');
	require_once(CLASSES_ROOT . 'database/table/catalog/CPersonBase.php');
	require_once(CLASSES_ROOT . 'database/table/catalog/CProductBase.php');
	require_once(CLASSES_ROOT . 'database/table/catalog/CSetupBase.php');
	require_once(CLASSES_ROOT . 'database/wrapper/CCatalogWrapper.php');
	//
	// Loading DB engine specific Table Classes
	//
   $sTableClassFolder = GetTableClassFolderByDBType();
	require_once(CLASSES_ROOT . "database/table/catalog/$sTableClassFolder/COrder.php");
	require_once(CLASSES_ROOT . "database/table/catalog/$sTableClassFolder/COrderDetail.php");
	require_once(CLASSES_ROOT . "database/table/catalog/$sTableClassFolder/COrderHistory.php");
	require_once(CLASSES_ROOT . "database/table/catalog/$sTableClassFolder/COrderTracking.php");
	require_once(CLASSES_ROOT . "database/table/catalog/$sTableClassFolder/CPaymentHistory.php");
	require_once(CLASSES_ROOT . "database/table/catalog/$sTableClassFolder/CPerson.php");
	require_once(CLASSES_ROOT . "database/table/catalog/$sTableClassFolder/CProduct.php");
	require_once(CLASSES_ROOT . "database/table/catalog/$sTableClassFolder/CSetup.php");
	}
//
// SellerDeck Extension module entry point
//
try
	{
	$sExtensionName = basename($sExtensionProgramDataPath);
	if (!HANDSHAKING)
		{
		\SDExtension\Helper\CLogger::get(LOG_CHANNEL_NAME)->addInfo("Loading extension: $sExtensionName");
		}
	$sExtensionBootstrap = EXTENSIONS_APP_ROOT . "app_bootstrap.php";
	if (!file_exists($sExtensionBootstrap))
		{
		\SDExtension\Helper\CLogger::get(LOG_CHANNEL_NAME)->addError(EXCEPTION_MSG_CANT_LOAD_EXTENSION . ": $sExtension #" . EXCEPTION_CODE_CANT_LOAD_EXTENSION);
		throw new \SDExtension\SDException\SDException(EXCEPTION_MSG_CANT_LOAD_EXTENSION . ": $sExtension", EXCEPTION_CODE_CANT_LOAD_EXTENSION);
		}
	require_once($sExtensionBootstrap);
	if (!HANDSHAKING)
		{
		\SDExtension\Helper\CLogger::get(LOG_CHANNEL_NAME)->addInfo("$sExtensionName loaded.");
		}
	}
catch (\SDExtension\SDException\SDException $oException)
	{
	if (!HANDSHAKING)
		{
		if ($oException instanceof \SDExtension\SDException\SDExitException)
			{
			\SDExtension\Helper\CLogger::get(LOG_CHANNEL_NAME)->addNotice($oException->getMessage());
			}
		else
			{
			\SDExtension\Helper\CLogger::get(LOG_CHANNEL_NAME)->addError($oException->getMessage());
			}
		}
	die($oException->getMessage());
	}
//
// Further constants, if not defined in extension
//
defined('ORDER_NUMBER_PREFIX') || define('ORDER_NUMBER_PREFIX', 'EXTORD');
defined('CHANNEL_NAME') || define('CHANNEL_NAME', 'SDDExt');
defined('SDE_VERSION') || define('SDE_VERSION', SDE_VERSION_MAJOR . "." . SDE_VERSION_MINOR . "." . SDE_VERSION_MAINTENANCE);
defined('SDE_VERSION_DAYNO') || define('SDE_VERSION_DAYNO', "1");

