<?php

/**
 * CControllerBase.php - Implementation file for AJAX Backend Controller Base class
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */

namespace SDExtension;

class CControllerBase
	{

	/**
	 * @var string $m_sAction Action
	 */
	protected $m_sAction = "";

	/**
	 * @var array $m_aResponse Response
	 */
	protected $m_aResponse = [];

	/**
	 * @var array $m_nOutputFormat Output Format
	 */
	protected $m_nOutputFormat = FORMAT_JSON;

	public function __call($sName, $aArguments)
		{
		echo $sName;
		return [
			'status' => 'success',
		];
		}

	/**
	 * __construct - Run process
	 * 
	 * @access public
	 * @param $aInput array Input data
	 * @return bool Success
	 */
	public function __construct()
		{

		$this->m_sAction = filter_input(INPUT_GET, CONTROLLER_PARAMETER_ACTION);
		if (null != $this->m_sAction)
			{
			$this->m_sAction = ucfirst($this->m_sAction);
			}
		else
			{
			$this->m_sAction = CONTROLLER_DEFAULT_ACTION;
			}
		$this->m_nOutputFormat = filter_input(INPUT_GET, CONTROLLER_PARAMETER_FORMAT);
		if (null != $this->m_nOutputFormat)
			{
			$this->m_nOutputFormat = strtolower($this->m_nOutputFormat);
			}
		else
			{
			$this->m_nOutputFormat = FORMAT_JSON;
			}
		}

	/**
	 * Run - Run process
	 * 
	 * @access public
	 * @return bool Success
	 */
	public function Run()
		{
		if (FORMAT_STREAM == $this->m_nOutputFormat)
			{
			sse_header();
			}
		$this->m_aResponse = $this->{"Action" . $this->m_sAction}();
		return $this;
		}

	/**
	 * SetOutputFormat - Set Output Format
	 * 
	 * @access public
	 * @return bool Success
	 */
	public function SetOutputFormat($nOutputFormat = FORMAT_JSON)
		{
		$this->m_nOutputFormat = $nOutputFormat;
		}

	/**
	 * GetStandardResponse - Get Standard Response
	 * 
	 * @access public
	 * @param $sAction string Action name
	 * @param $sStatus string Status
	 * @param $aData array Data
	 * @param $sView string View
	 * @return array Response data
	 */
	public function GetStandardResponse($sAction = '', $sStatus = STATUS_SUCCESS, $aData = [], $sView = '')
		{
		return [
			'action' => $sAction,
			'status' => $sStatus,
			'data' => $aData,
			'view' => $sView,
		];
		}

	/**
	 * GetOutput - Get Output
	 * 
	 * @access public
	 * @return bool Success
	 */
	public function GetOutput($nOutputFormat = null)
		{
		if (null == $nOutputFormat)
			{
			$nOutputFormat = $this->m_nOutputFormat;
			}
		switch ($nOutputFormat)
			{
			case FORMAT_ARRAY:
				return $this->m_aResponse;
			case FORMAT_TEXT:
				header('Content-Type: text/plain');
				return print_r($this->m_aResponse, true);
			case FORMAT_STREAM:
				return "data: " . json_encode($this->m_aResponse);
			case FORMAT_PHP:
				header('Content-Type: text/plain');
				return var_export($this->m_aResponse, true);
			case FORMAT_HTML:
				header('Content-Type: text/html');
				return arr_get($this->m_aResponse, 'view', '');
//			case FORMAT_YAML:
//				header('Content-Type: application/xml');
//				return Array2XML($this->m_aResponse);
//			case FORMAT_XML:
//				header('Content-Type: application/xml');
//				return Array2XML($this->m_aResponse);
			case FORMAT_JSON:
			default:
				header('Content-Type: application/json');
				return json_encode($this->m_aResponse);
			}
		return $this->m_aResponse;
		}

	}
