<?php

/**
 * COrderBase.php - Implementation of Catalog/Order table class.
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */

namespace SDExtension\DB\Table;

if (!defined('TABLE_ORDER'))
	{
	define('TABLE_ORDER', 'Order');
	}

class COrderBase extends CTable
	{

	/**
	 * @var string $m_sTable Table
	 */
	protected $m_sTable = TABLE_ORDER;

	/**
	 * @var string $m_sIdColumn ID Column name
	 */
	protected $m_sIdColumn = 'Order Sequence Number';

	/**
	 * @var array $m_aDefaultValues Default Values
	 */
	protected $m_aDefaultValues = [
		'Order Sequence Number' => '',
		'Order Number' => '',
		'Version' => 1,
		'Program Version' => '6AAA',
		'Update Count' => 1,
		'IP address' => null,
		'Status' => 'N',
		'Currency' => 'GPB',
		'sUserDefinedPayment' => null,
		'Movement' => 0,
		'Reason For Purchase' => null,
		'How Find Site' => null,
		'sUserDefinedGeneral' => ' ',
		'Total Cost' => 0,
		'Discount Cost' => 0,
		'Sub-heading Cost' => 0,
		'Shipping Total Cost' => 0,
		'Shipping Tax Treatment' => 0,
		'Shipping Tax Cost 1' => 0,
		'Shipping Tax Cost 2' => 0,
		'sUserDefinedShipping' => null,
		'Tax Total Cost 1' => 0,
		'Tax Total Cost 2' => 0,
		'sUserDefinedTax' => null,
		'Order Total Cost' => 0,
		'Total Lines' => 0,
		'Total Lines Shipped' => 0,
		'Total Lines Cancelled' => 0,
		'Credit Card Expiry Date' => null,
		'sCreditCardStartDate' => null,
		'Date Ordered' => '',
		'Date Received' => '',
		'PO Number' => null,
		'Date Order Finished' => null,
		'Adjustment Message' => null,
		'Original Tax Cost 1' => 0,
		'Original Tax Cost 2' => 0,
		'Original Shipping Cost' => 0,
		'Original Shipping Tax Treatment' => 0,
		'Original Shipping Tax Cost 1' => 0,
		'Original Shipping Tax Cost 2' => 0,
		'Original Order Cost' => 0,
		'Original Sub-heading Cost' => 0,
		'Original Discount Cost' => 0,
		'Original Total Cost' => 0,
		'ReportNumber' => 0,
		'InvoiceContactID' => 0,
		'DeliverContactID' => 0,
		'CC Authorization code' => null,
		'sReferenceNumber' => null,
		'sOpaqueShipData' => '',
		'sCatalogKey' => null,
		'sShippingDescription' => '',
		'nPaymentStatus' => '10',
		'nInvoiceStatus' => 0,
		'nBomStatus' => 0,
		'sDateCCPrinted' => '',
		'Discount Percent' => 0,
		'Tax Percent 1' => 0,
		'Tax Percent 2' => 0,
		'Original Discount Percent' => 0,
		'Original Tax Percent 1' => 0,
		'Original Tax Percent 2' => 0,
		'Payment Option' => '10002',
		'nTotalLinesBackOrdered' => 0,
		'sBackorderNumber' => null,
		'nParentSequenceNumber' => 0,
		'sChecksum' => null,
		'sDeliveryCountryCode' => null,
		'sDeliveryRegionCode' => null,
		'sInvoiceCountryCode' => null,
		'sInvoiceRegionCode' => null,
		'dHandlingCost' => 0,
		'nHandlingTaxTreatment' => 0,
		'dHandlingTax1' => 0,
		'dHandlingTax2' => 0,
		'dOriginalHandlingCost' => 0,
		'nOriginalHandlingTaxTreatment' => 0,
		'dOriginalHandlingTax1' => 0,
		'dOriginalHandlingTax2' => 0,
		'sOpaqueHandlingData' => 'Handling;0;',
		'sHandlingDescription' => null,
		'sTax1OpaqueData' => 'VAT=2=0=0=0=0=0=3=',
		'sTax2OpaqueData' => '=0=0=0=0=0=0=0=',
		'sTaxModelOpaqueData' => '1=2=0=0=0=Zero-Rated=0=0=0==0=0=0==0=0=0==',
		'sOrigTaxModelOpaqueData' => '1=2=0=0=0=Zero-Rated=0=0=0==0=0=0==0=0=0==',
		'sOrigTax1OpaqueData' => '=0=0=0=0=0=0=0=',
		'sOrigTax2OpaqueData' => '=0=0=0=0=0=0=0=',
		'bTax1UserExempt' => 0, //false
		'bTax2UserExempt' => 0, //false
		'sTax1ExemptionData' => null,
		'sTax2ExemptionData' => null,
		'nBuyerID' => -1,
		'nCustomerID' => -1,
		'nTotalItemsOrdered' => 0,
		'nTotalItemsShipped' => 0,
		'nTotalItemsCancelled' => 0,
		'nTotalItemsBackOrdered' => 0,
		'bOrderIsDeleted' => 0, //false
		'Credit Card Type' => null,
		'sTax1ShippingCode' => SQL_TYPE_STRING . '000',
		'sTax2ShippingCode' => SQL_TYPE_STRING . '000',
		'sTax1HandlingCode' => SQL_TYPE_STRING . '000',
		'sTax2HandlingCode' => SQL_TYPE_STRING . '000',
		'sTax1Name' => null,
		'sTax2Name' => null,
		'dTax1ShippingRate' => 0,
		'dTax1HandlingRate' => 0,
		'dTax2ShippingRate' => 0,
		'dTax2HandlingRate' => 0,
		'sCreditCardVV2' => SQL_TYPE_STRING . '-1',
		'nSSPProviderID' => -1,
		'sSSPOpaqueData' => null,
		'nPreauthReportNumber' => 0,
		'sWorldShipExportDate' => null,
		'nTax1Id' => 0,
		'nTax2Id' => 0,
		'sSeparatePackageDetails' => null,
		'sMixedPackageDetails' => null,
		'dOriginalOrderAdjustments' => 0,
		'sCouponCode' => null,
		'bECI' => 0, //false
		'nColor' => -1,
		'bOfflineOrder' => 0, //false
		'sJournal' => null,
		'bTermsAccepted' => 0, //false
		'sCreditCardIssueNumber' => SQL_TYPE_STRING . '-1',
		'bLockedForReport' => 0, //false
		'sOriginalCustOrd' => 'U',
		'nEncryptionType' => 0,
		'Credit Card Number' => null,
		'sEncryptionData' => null,
		'Update Date' => '',
		'Action Due Date' => null,
		'bOngoingOrder' => 0, //false
		'bTaxInclusiveMode' => true,
		'bZoneTax1Applies' => true,
		'bZoneTax2Applies' => 0, //false
		'bTransferedToEPOS' => 0, //false
		'sInvoiceNumber' => null,
		'sTaxPoint' => null,
		'nFraudState' => 0,
		'ePickedStatus' => 0,
		'bSentToFeefo' => 0, //false
		'sTrackingCode' => null,
		'bUseDatePromptAsDeliveryDate' => 0, //false
		'nCustomMessageStatusID' => 0,
		'nCarrierStatus' => 0,
		'sCarrierName' => null,
		'sCarrierClassOfService' => null,
		'sCarrierLabelPrintedDate' => null,
		'sCarrierShipmentCommittedDate' => null,
		'sCarrierMessage' => null,
		'sDespatchDate' => null,
		'bGFSAddressValidated' => 0, //false
		'bInternationalShipping' => 0, //false
		'nNumPackages' => -1,
		'dTotalWeight' => -1,
		'sChannelName' => '',
		'sOriginalShipClass' => 'Unknown',
	];

	/**
	 * CreateOriginalCopies - Creates Original Copies
	 *
	 * @access public
	 * @return void
	 */
	public function CreateOriginalCopies()
		{
		$this->m_aActualValues['Original Discount Percent'] = $this->m_aActualValues['Discount Percent'];
		$this->m_aActualValues['nOriginalHandlingTaxTreatment'] = $this->m_aActualValues['nHandlingTaxTreatment'];
		$this->m_aActualValues['Original Tax Percent 1'] = $this->m_aActualValues['Tax Percent 1'];
		$this->m_aActualValues['Original Tax Percent 2'] = $this->m_aActualValues['Tax Percent 2'];
		$this->m_aActualValues['sOrigTax1OpaqueData'] = $this->m_aActualValues['sTax1OpaqueData'];
		$this->m_aActualValues['sOrigTax2OpaqueData'] = $this->m_aActualValues['sTax2OpaqueData'];
		$this->m_aActualValues['sOrigTaxModelOpaqueData'] = $this->m_aActualValues['sTaxModelOpaqueData'];
		$this->m_aActualValues['Original Discount Cost'] = $this->m_aActualValues['Discount Cost'];
		$this->m_aActualValues['dOriginalHandlingCost'] = $this->m_aActualValues['dHandlingCost'];
		$this->m_aActualValues['dOriginalHandlingTax1'] = $this->m_aActualValues['dHandlingTax1'];
		$this->m_aActualValues['dOriginalHandlingTax2'] = $this->m_aActualValues['dHandlingTax2'];
		$this->m_aActualValues['Original Shipping Cost'] = $this->m_aActualValues['Shipping Total Cost'];
		$this->m_aActualValues['Original Sub-heading Cost'] = $this->m_aActualValues['Sub-heading Cost'];
		$this->m_aActualValues['Original Shipping Tax Cost 1'] = $this->m_aActualValues['Shipping Tax Cost 1'];
		$this->m_aActualValues['Original Shipping Tax Cost 2'] = $this->m_aActualValues['Shipping Tax Cost 2'];
		$this->m_aActualValues['Original Tax Cost 1'] = $this->m_aActualValues['Tax Total Cost 1'];
		$this->m_aActualValues['Original Tax Cost 2'] = $this->m_aActualValues['Tax Total Cost 2'];
		$this->m_aActualValues['Original Order Cost'] = $this->m_aActualValues['Order Total Cost'];
		$this->m_aActualValues['Original Total Cost'] = $this->m_aActualValues['Total Cost'];
		}

	}
