<?php

/**
 * CFieldMapping.php - Abstract Field Mapping class.
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */

namespace SDExtension\Import;

abstract class CFieldMapping
	{

	/**
	 * @var object $m_oTax Tax Module
	 */
	protected $m_oTax = null;

	/**
	 * @var object $m_oValidator Validator
	 */
	protected $m_oValidator = null;

	/**
	 * @var object $m_oCatalogDB Catalog DB
	 */
	protected $m_oCatalogDB = null;

	/**
	 * @var object $m_oShippingDB Shipping DB
	 */
	protected $m_oShippingDB = null;

	/**
	 * @var string $m_sCurrentDate Current Date
	 */
	protected $m_sCurrentDate = "";

	/**
	 * @var object $m_dDefaultWeight Default Weight
	 */
	protected $m_dDefaultWeight = DEFAULT_WEIGHT;

	/**
	 * __construct - Object constructor
	 *
	 * @access public
	 * @param object $oCatalogDB Catalog DB
	 * @param object $oShippingDB Shipping DB
	 * @return void
	 */
	public function __construct($oCatalogDB, $oShippingDB)
		{
		$this->m_oValidator = new \SDExtension\Helper\CValidator($oCatalogDB, $oShippingDB);
		$this->m_oTax = new \SDExtension\CTax($oCatalogDB, $oShippingDB);
		$this->m_oCatalogDB = $oCatalogDB;
		$this->m_oShippingDB = $oShippingDB;
		$this->m_sCurrentDate = SellerDeckDate();
		$oQueryResult = $this->m_oShippingDB->Select(TABLE_WEIGHT_CONFIGURATION, 'sDefaultWeight', [['nID', 0]]);
		if ($oQueryResult !== false)
			{
			$aControlInfo = $oQueryResult->fetch(\PDO::FETCH_ASSOC);
			$this->m_dDefaultWeight = (double) arr_get($aControlInfo, 'sDefaultWeight', DEFAULT_WEIGHT);
			}
		}

	/**
	 * MapOrders - Maps Orders
	 *
	 * @access protected
	 * @param array $aGetOrdersResult GetOrders() Result
	 */
	abstract protected function MapOrders($aGetOrdersResult);

	/**
	 * MapOrders - Maps Orders
	 *
	 * @access protected
	 * @param array $aGetOrdersResult GetOrders() Result
	 */
	abstract protected function GenerateOrderNumber($sExternalOrderID);

	/**
	 * GetProductByReference - Getting Product by Reference
	 * 
	 * @access protected
	 * @param string $sProductReference Product Reference
	 * @return array Product
	 */
	protected function GetProductByReference($sProductReference)
		{
		$oQueryResult = $this->m_oCatalogDB->Select(TABLE_PRODUCT, '*', [['Product Reference', SQL_TYPE_STRING . $sProductReference]]);
		if ($oQueryResult === false)
			{
			return [];
			}
		return $oQueryResult->fetch(\PDO::FETCH_ASSOC);
		}

	/**
	 * GetProductByBarcode - Getting Product by Barcode
	 * 
	 * @access protected
	 * @param string $sBarcode Barcode
	 * @return array Product
	 */
	protected function GetProductByBarcode($sBarcode)
		{
		$oQueryResult = $this->m_oCatalogDB->Select(TABLE_PRODUCT, ['Product Reference'], [['sBarcode', SQL_TYPE_STRING . $sBarcode]]);
		if ($oQueryResult === false)
			{
			return [];
			}
		return $oQueryResult->fetch(\PDO::FETCH_ASSOC);
		}

	/**
	 * GetProductPropertiesByBarcode - Getting Product Properties by Barcode
	 * 
	 * @access protected
	 * @param string $sBarcode Barcode
	 * @return array Product Properties
	 */
	protected function GetProductPropertiesByBarcode($sBarcode)
		{
		$oQueryResult = $this->m_oCatalogDB->Select(TABLE_PRODUCT_PROPERTIES, '*', [['nType', 8], ['sString4', SQL_TYPE_STRING . $sBarcode]]);
		if ($oQueryResult === false)
			{
			return [];
			}
		return $oQueryResult->fetch(\PDO::FETCH_ASSOC);
		}

	}
