<?php

/**
 * CSDApiSoapClient.php - Implementation file for SellerDeck SOAP API class.
 * 
 * @package     SellerDeck Extensions
 * 
 * @author      Péter Erdődi
 * @copyright   © SellerDeck Ltd 2015. All rights reserved.
 */

namespace SDExtension;

class CSDApiSoapClient
	{

	/**
	 * @const int Maximum number of retry loops when a Soap Call fails
	 */
	const MAX_WAIT = 100;

	/**
	 * @var SoapClient Soap Client Object
	 */
	private $m_oSoapClient;

	/**
	 * @var bool Do we use retry loop or not when a Soap Call fails?
	 */
	private $m_bSoapCallLoop;

	/**
	 * __construct - Object constructor method
	 * 
	 * Initializes the member variables
	 *
	 * @access public
	 * @param SoapClient $oSoapClient Soap Client Object
	 * @param bool $bSoapCallLoop Do we use retry loop or not when a Soap Call fails?
	 * @return void
	 */
	public function __construct($oSoapClient = null, $bSoapCallLoop = false)
		{
		$this->m_oSoapClient = $oSoapClient;
		$this->m_bSoapCallLoop = $bSoapCallLoop;
		}

	/**
	 * __call - Soap Function caller (PHP Magic Method)
	 *
	 * @access public
	 * @param string $sFuncName Soap Function name
	 * @param array $aArguments Soap Function arguments
	 * @return int Error code
	 * @return mixed Soap Function call result
	 */
	public function __call($sFuncName, $aArguments)
		{
		//
		// Do we use retry loop or not when a Soap Call fails?
		//
        if ($this->m_bSoapCallLoop)
			{
			//
			// The Result variable is null by default
			//
            $nResult = null;
			//
			// Loop counter
			//
            $iCount = 0;
			do
				{
				//
				// Sleep time is increasing by each loop
				// * 1000 means we ccount in milliseconds, not microseconds
				//
                usleep($iCount * 1000);
				$iCount++;
				//
				// Calling Soap Function
				//
                $nResult = $this->m_oSoapClient->__call($sFuncName, $aArguments);
				}
			//
			// Do that, while there's an error...
			//
            while ($nResult instanceof SoapFault && $iCount < self::MAX_WAIT);
			//
			// Returns the Function result or error, if there were errors MAX_WAIT times
			//
            return $nResult;
			}
		else
			{
			//
			// Returns the Function result or error
			//
            return $this->m_oSoapClient->__call($sFuncName, $aArguments);
			}
		}

	}
